==> manaplus_1.3.10.12.orig.tar.xz: manaplus-1.3.10.12/src/particle/rotationalparticle.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2006-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2013  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PARTICLE_ROTATIONALPARTICLE_H
#define PARTICLE_ROTATIONALPARTICLE_H

#include "particle/imageparticle.h"

#include "utils/xml.h"

class Animation;
class Map;
class SimpleAnimation;

class RotationalParticle final : public ImageParticle
{
    public:
        RotationalParticle(Map *const map, Animation *const animation);

        RotationalParticle(Map *const map, const XmlNodePtr animationNode,
                           const std::string& dyePalettes = std::string());

        A_DELETE_COPY(RotationalParticle)

        ~RotationalParticle();

        bool update() override;

    private:
        SimpleAnimation *mAnimation; /**< Used animation for this particle */
};

#endif  // PARTICLE_ROTATIONALPARTICLE_H

==> manaplus_1.3.11.24.orig.tar.xz: manaplus-1.3.11.24/src/particle/rotationalparticle.h <==
/*
 *  The ManaPlus Client
 *  Copyright (C) 2006-2009  The Mana World Development Team
 *  Copyright (C) 2009-2010  The Mana Developers
 *  Copyright (C) 2011-2013  The ManaPlus Developers
 *
 *  This file is part of The ManaPlus Client.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef PARTICLE_ROTATIONALPARTICLE_H
#define PARTICLE_ROTATIONALPARTICLE_H

#include "particle/imageparticle.h"

#include "utils/xml.h"

class Animation;
class SimpleAnimation;

class RotationalParticle final : public ImageParticle
{
    public:
        explicit RotationalParticle(Animation *const animation);

        explicit RotationalParticle(const XmlNodePtr animationNode,
                                    const std::string& dyePalettes
                                    = std::string());

        A_DELETE_COPY(RotationalParticle)

        ~RotationalParticle();

        bool update() override final;

    private:
        SimpleAnimation *mAnimation; /**< Used animation for this particle */
};

#endif  // PARTICLE_ROTATIONALPARTICLE_H
